@@ -3,7 +3,7 @@ import re
 
 pkgConfigPath = os.environ.get("PKG_CONFIG_PATH")
 if pkgConfigPath is None:
-    pkgConfigPath = ''
-pathList = re.split(':', pkgConfigPath)
+    pkgConfigPath = ""
+pathList = re.split(":", pkgConfigPath)
 
 print(pathList)
